@@ -1,6 +1,6 @@
-from .oxide import *
+from .oxide import weibull_model
 
 
 __doc__ = oxide.__doc__
 if hasattr(oxide, "__all__"):
-	__all__ = oxide.__all__
\ No newline at end of file
+	__all__ = oxide.__all__
